local_hero_transform library
Classes
- BaseHeroCard
- The base widget that builds the actual card content.
- CardGridView
- A card widget designed for grid view with hero animation capabilities.
- CardListView
- A card widget designed for list view with hero animation capabilities.
- CardStyleMode
- CustomShimmer
- HexColor
- ItemsModel
- Data model for hero card content and styling.
- LocalHero
- LocalHero widget that provides a tabbed navigation with smooth transitions.
- LocalHeroViews
- A widget that displays items in either grid or list view with hero animations.
- ShimmerBaseHeroCard